@@ -74,6 +74,7 @@ sub test_database_handle {
 
     ## Create the test database directory if it does not exist
     my $dbdir = $arg->{dbdir} || $self->{dbdir};
+    $DEBUG and warn qq{Datadir: $dbdir\n};
     if (! -d $dbdir) {
 
         -e $dbdir and die qq{Oops: I cannot create "$dbdir", there is already a file there!\n};
@@ -81,14 +82,19 @@ sub test_database_handle {
         Test::More::diag qq{Creating database in directory "$dbdir"\n};
 
         mkdir $dbdir;
+    }
+
+    my $datadir = "$dbdir/data space";
+    if (! -e $datadir) {
 
         my $initdb
             = $ENV{PGINITDB} ? $ENV{PGINITDB}
             : $ENV{PGBINDIR} ? "$ENV{PGBINDIR}/initdb"
             :                  'initdb';
 
-        $com = qq{LC_ALL=en LANG=C $initdb --locale=C -E UTF8 -D "$dbdir/data space" 2>&1};
+        $com = qq{LC_ALL=en LANG=C $initdb --locale=C -E UTF8 -D "$datadir" 2>&1};
         eval {
+            $DEBUG and warn qq{About to run: $com\n};
             $info = qx{$com};
         };
         if ($@) {
@@ -99,6 +105,7 @@ sub test_database_handle {
         my $cfile = "$dbdir/data space/postgresql.conf";
         open my $cfh, '>>', $cfile or die qq{Could not open "$cfile": $!\n};
         print $cfh qq{\n\n## check_postgres.pl testing parameters\n};
+        print $cfh qq{port = 5432\n};
         print $cfh qq{listen_addresses = ''\n};
         print $cfh qq{max_connections = 10\n};
 
@@ -188,6 +195,7 @@ sub test_database_handle {
 
         $com = qq{LC_ALL=en LANG=C $pg_ctl -o '-k $sockdir' -l $logfile -D "$dbdir/data space" start};
         eval {
+            $DEBUG and warn qq{About to run: $com\n};
             $info = qx{$com};
         };
         if ($@) {
@@ -249,7 +257,7 @@ sub test_database_handle {
                 $SQL = qq{SELECT * FROM pg_language WHERE lanname = '$lang'};
                 $res = qx{psql -Ax -qt -d postgres -q -h "$host" -c "$SQL"};
                 if ($res !~ /$lang/) {
-                    my $createlang = $ENV{PGBINDIR} ? "$ENV{PGBINDIR}/createlang" : 'pg_ctl';
+                    my $createlang = $ENV{PGBINDIR} ? "$ENV{PGBINDIR}/createlang" : 'createlang';
                     $COM = qq{$createlang -d postgres -h "$host" $lang};
                     system $COM;
                     }
@@ -277,7 +285,7 @@ sub test_database_handle {
     }
 
     $self->{dbname} ||= 'postgres';
-    my $dsn = qq{dbi:Pg:host=$dbhost;dbname=$self->{dbname}};
+    my $dsn = qq{dbi:Pg:host=$dbhost;port=5432;dbname=$self->{dbname}};
     my $dbuser = $self->{testuser};
     my @superdsn = ($dsn, $dbuser, '', {AutoCommit=>0,RaiseError=>1,PrintError=>0});
     my $dbh;
@@ -421,7 +429,7 @@ sub run {
     my $dbuser = $self->{testuser} || die 'No testuser?';
     my $dbname = $self->{dbname} || die 'No dbname?';
 
-    my $com = qq{perl check_postgres.pl --no-check_postgresrc --action=$action};
+    my $com = qq{perl check_postgres.pl --no-check_postgresrc --dbport=5432 --action=$action};
     if ($extra !~ /dbhost/) {
         $com .= qq{ --dbhost="$dbhost"};
     }
